==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/da3/structCFollowTrackT.js <==
var structCFollowTrackT =
[
    [ "ErrorCode", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5", [
      [ "EC_NONE", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5abef9fb6564402381c3388ae23ae65b24", null ],
      [ "EC_OWNER", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a307ea24a6330c6c3eb094ca531f5b55a", null ],
      [ "EC_RAIL_TYPE", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5aa87fed2bdf3997e05f768371cf910b0d", null ],
      [ "EC_90DEG", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a4fb9bcafabdb2912be594be8f33854e8", null ],
      [ "EC_NO_WAY", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5aa9c756236390219df759693f18dd0c4e", null ],
      [ "EC_RESERVED", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a179b04dea5c01805759cb5756fe2fba6", null ]
    ] ],
    [ "CFollowTrackT", "d0/da3/structCFollowTrackT.html#ab288daae5c61355b547b051ae34c18ea", null ],
    [ "CFollowTrackT", "d0/da3/structCFollowTrackT.html#a9fea3d903c5a454d181be0167c5b3db4", null ],
    [ "Allow90degTurns", "d0/da3/structCFollowTrackT.html#ad7f470b7b5de07d95a81080d758a92b1", null ],
    [ "CanEnterNewTile", "d0/da3/structCFollowTrackT.html#a3a6869f88a822b5c1e1a60c13362f0f9", null ],
    [ "CanExitOldTile", "d0/da3/structCFollowTrackT.html#a256bf4cefe4111242ce137329b8b638d", null ],
    [ "DoTrackMasking", "d0/da3/structCFollowTrackT.html#a2129309a19aeb1c391a55948218969d8", null ],
    [ "Follow", "d0/da3/structCFollowTrackT.html#a295b0c238ab0211d5180376f09e1a8ca", null ],
    [ "FollowTileExit", "d0/da3/structCFollowTrackT.html#ab236fc5839934d03ba1c1191bf7aa36d", null ],
    [ "ForcedReverse", "d0/da3/structCFollowTrackT.html#a8d808ff6a8827eaad5b1616dea5e601b", null ],
    [ "GetSingleTramBit", "d0/da3/structCFollowTrackT.html#af36cd10ff3c423bb3529259a3cd7bdc5", null ],
    [ "GetSpeedLimit", "d0/da3/structCFollowTrackT.html#aa3cc87c54ce049b56840794798fbf306", null ],
    [ "Init", "d0/da3/structCFollowTrackT.html#a289f7ddcdd1ee3bf146b9f23195d2a17", null ],
    [ "Init", "d0/da3/structCFollowTrackT.html#a41d9da876ff91b9335c242047ea9a014", null ],
    [ "IsRailTT", "d0/da3/structCFollowTrackT.html#adf0f99cb833f9ea261f7a8c11e36ee0a", null ],
    [ "IsRoadTT", "d0/da3/structCFollowTrackT.html#a7375ea36d78b5cab24cb40ada3cc6425", null ],
    [ "IsTram", "d0/da3/structCFollowTrackT.html#ac2cd3f34271dd0d1c6fbea5ab15483fa", null ],
    [ "IsWaterTT", "d0/da3/structCFollowTrackT.html#a35b9cf0ce8db15be01c2ba9a7ea8eb69", null ],
    [ "MaskReservedTracks", "d0/da3/structCFollowTrackT.html#af66b1ee17c0875fb08fe9cc0b2515e28", null ],
    [ "QueryNewTileTrackStatus", "d0/da3/structCFollowTrackT.html#a4da79a8bd7ddba90c5c0053439310026", null ],
    [ "TryReverse", "d0/da3/structCFollowTrackT.html#a5c42dcf4b9324a3523b5b272a485e178", null ],
    [ "TT", "d0/da3/structCFollowTrackT.html#aa5e7c93d16277480502620955a9ad5af", null ],
    [ "m_err", "d0/da3/structCFollowTrackT.html#acecd7992372b9145b02fc707dbb81dd0", null ],
    [ "m_exitdir", "d0/da3/structCFollowTrackT.html#a397c0807dcb0413796f01cf54ce01d50", null ],
    [ "m_is_bridge", "d0/da3/structCFollowTrackT.html#ab7c50f09b5ca9965f99f07cff9f7cc68", null ],
    [ "m_is_station", "d0/da3/structCFollowTrackT.html#a0850bc886407498e7c922f0284ec94d6", null ],
    [ "m_is_tunnel", "d0/da3/structCFollowTrackT.html#a216bc8f452b1313dfce9614d665df1fe", null ],
    [ "m_new_td_bits", "d0/da3/structCFollowTrackT.html#ad76c938c48b81594454ad00d30b98ee2", null ],
    [ "m_new_tile", "d0/da3/structCFollowTrackT.html#a7d3bae82dfb63f2687f14c550325e81f", null ],
    [ "m_old_td", "d0/da3/structCFollowTrackT.html#ac2b4da1f8119c6aa47b7f50995fe1a19", null ],
    [ "m_old_tile", "d0/da3/structCFollowTrackT.html#a1884b325924d096962872543cb8bfc32", null ],
    [ "m_pPerf", "d0/da3/structCFollowTrackT.html#a902d042fe52cf34e9b91869b7ddd0d15", null ],
    [ "m_railtypes", "d0/da3/structCFollowTrackT.html#ae1a829838edd8f83e83ba2aaf70b623f", null ],
    [ "m_tiles_skipped", "d0/da3/structCFollowTrackT.html#ac6896ab135e60aad5b8a319044ffdc79", null ],
    [ "m_veh", "d0/da3/structCFollowTrackT.html#a8fee0a55ff0584df9632151cbd6f4a9b", null ],
    [ "m_veh_owner", "d0/da3/structCFollowTrackT.html#aed768aa33eecce48ee447545d153962a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/da3/structCFollowTrackT.js <==
var structCFollowTrackT =
[
    [ "ErrorCode", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5", [
      [ "EC_NONE", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5abef9fb6564402381c3388ae23ae65b24", null ],
      [ "EC_OWNER", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a307ea24a6330c6c3eb094ca531f5b55a", null ],
      [ "EC_RAIL_ROAD_TYPE", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a4dcbb3be11ea5e674f4ebf23bd52d860", null ],
      [ "EC_90DEG", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a4fb9bcafabdb2912be594be8f33854e8", null ],
      [ "EC_NO_WAY", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5aa9c756236390219df759693f18dd0c4e", null ],
      [ "EC_RESERVED", "d0/da3/structCFollowTrackT.html#a0187e483c0d00a6e837215d3906d3cd5a179b04dea5c01805759cb5756fe2fba6", null ]
    ] ],
    [ "CFollowTrackT", "d0/da3/structCFollowTrackT.html#a52ed4aefcd5f31b6b01d1bd44a777198", null ],
    [ "CFollowTrackT", "d0/da3/structCFollowTrackT.html#af0031cae66066654335ee0dc61c6e6c6", null ],
    [ "Allow90degTurns", "d0/da3/structCFollowTrackT.html#ad7f470b7b5de07d95a81080d758a92b1", null ],
    [ "CanEnterNewTile", "d0/da3/structCFollowTrackT.html#a3a6869f88a822b5c1e1a60c13362f0f9", null ],
    [ "CanExitOldTile", "d0/da3/structCFollowTrackT.html#a256bf4cefe4111242ce137329b8b638d", null ],
    [ "DoTrackMasking", "d0/da3/structCFollowTrackT.html#a2129309a19aeb1c391a55948218969d8", null ],
    [ "Follow", "d0/da3/structCFollowTrackT.html#a295b0c238ab0211d5180376f09e1a8ca", null ],
    [ "FollowTileExit", "d0/da3/structCFollowTrackT.html#ab236fc5839934d03ba1c1191bf7aa36d", null ],
    [ "ForcedReverse", "d0/da3/structCFollowTrackT.html#a8d808ff6a8827eaad5b1616dea5e601b", null ],
    [ "GetSingleTramBit", "d0/da3/structCFollowTrackT.html#af36cd10ff3c423bb3529259a3cd7bdc5", null ],
    [ "GetSpeedLimit", "d0/da3/structCFollowTrackT.html#a843f173ff23aeca813d168aa1823258a", null ],
    [ "Init", "d0/da3/structCFollowTrackT.html#a289f7ddcdd1ee3bf146b9f23195d2a17", null ],
    [ "Init", "d0/da3/structCFollowTrackT.html#a41d9da876ff91b9335c242047ea9a014", null ],
    [ "IsRailTT", "d0/da3/structCFollowTrackT.html#adf0f99cb833f9ea261f7a8c11e36ee0a", null ],
    [ "IsRoadTT", "d0/da3/structCFollowTrackT.html#a7375ea36d78b5cab24cb40ada3cc6425", null ],
    [ "IsTram", "d0/da3/structCFollowTrackT.html#ac2cd3f34271dd0d1c6fbea5ab15483fa", null ],
    [ "IsWaterTT", "d0/da3/structCFollowTrackT.html#a35b9cf0ce8db15be01c2ba9a7ea8eb69", null ],
    [ "MaskReservedTracks", "d0/da3/structCFollowTrackT.html#af66b1ee17c0875fb08fe9cc0b2515e28", null ],
    [ "QueryNewTileTrackStatus", "d0/da3/structCFollowTrackT.html#a4da79a8bd7ddba90c5c0053439310026", null ],
    [ "TryReverse", "d0/da3/structCFollowTrackT.html#a5c42dcf4b9324a3523b5b272a485e178", null ],
    [ "TT", "d0/da3/structCFollowTrackT.html#aa5e7c93d16277480502620955a9ad5af", null ],
    [ "m_err", "d0/da3/structCFollowTrackT.html#acecd7992372b9145b02fc707dbb81dd0", null ],
    [ "m_exitdir", "d0/da3/structCFollowTrackT.html#a397c0807dcb0413796f01cf54ce01d50", null ],
    [ "m_is_bridge", "d0/da3/structCFollowTrackT.html#ab7c50f09b5ca9965f99f07cff9f7cc68", null ],
    [ "m_is_station", "d0/da3/structCFollowTrackT.html#a0850bc886407498e7c922f0284ec94d6", null ],
    [ "m_is_tunnel", "d0/da3/structCFollowTrackT.html#a216bc8f452b1313dfce9614d665df1fe", null ],
    [ "m_new_td_bits", "d0/da3/structCFollowTrackT.html#ad76c938c48b81594454ad00d30b98ee2", null ],
    [ "m_new_tile", "d0/da3/structCFollowTrackT.html#a7d3bae82dfb63f2687f14c550325e81f", null ],
    [ "m_old_td", "d0/da3/structCFollowTrackT.html#ac2b4da1f8119c6aa47b7f50995fe1a19", null ],
    [ "m_old_tile", "d0/da3/structCFollowTrackT.html#a1884b325924d096962872543cb8bfc32", null ],
    [ "m_pPerf", "d0/da3/structCFollowTrackT.html#a902d042fe52cf34e9b91869b7ddd0d15", null ],
    [ "m_railtypes", "d0/da3/structCFollowTrackT.html#ae1a829838edd8f83e83ba2aaf70b623f", null ],
    [ "m_tiles_skipped", "d0/da3/structCFollowTrackT.html#ac6896ab135e60aad5b8a319044ffdc79", null ],
    [ "m_veh", "d0/da3/structCFollowTrackT.html#a8fee0a55ff0584df9632151cbd6f4a9b", null ],
    [ "m_veh_owner", "d0/da3/structCFollowTrackT.html#aed768aa33eecce48ee447545d153962a", null ]
];
